@@ -1,6 +1,6 @@
 package DBIx::Custom;
 
-our $VERSION = '0.1636';
+our $VERSION = '0.1637';
 
 use 5.008001;
 use strict;
@@ -18,10 +18,9 @@ use Encode qw/encode_utf8 decode_utf8/;
 
 __PACKAGE__->attr(
     [qw/data_source dbh password user/],
-    dbi_options => sub { {} },
     cache => 1,
-    filter_check  => 1,
-    query_builder => sub {DBIx::Custom::QueryBuilder->new},
+    dbi_option => sub { {} },
+    query_builder => sub { DBIx::Custom::QueryBuilder->new },
     result_class  => 'DBIx::Custom::Result',
     table_class   => 'DBIx::Custom::Table'
 );
@@ -165,7 +164,7 @@ sub connect {
       unless $data_source;
     my $user        = $self->user;
     my $password    = $self->password;
-    my $dbi_options = $self->dbi_options || {};
+    my $dbi_option = {%{$self->dbi_options}, %{$self->dbi_option}};
     
     # Connect
     my $dbh = eval {DBI->connect(
@@ -176,7 +175,7 @@ sub connect {
             RaiseError => 1,
             PrintError => 0,
             AutoCommit => 1,
-            %$dbi_options
+            %$dbi_option
         }
     )};
     
@@ -224,7 +223,7 @@ sub create_query {
     # Prepare statement handle
     my $sth;
     eval { $sth = $self->dbh->prepare($query->{sql})};
-    $self->_croak($@, qq{. SQL: "$query->{sql}"}) if $@;
+    $self->_croak($@, qq{. Following SQL is executed. "$query->{sql}"}) if $@;
     
     # Set statement handle
     $query->sth($sth);
@@ -340,7 +339,7 @@ sub execute{
     my $sth      = $query->sth;
     my $affected;
     eval {$affected = $sth->execute(@$binds)};
-    $self->_croak($@) if $@;
+    $self->_croak($@, qq{. Following SQL is executed. "$query->{sql}"}) if $@;
     
     # Return resultset if select statement is executed
     if ($sth->{NUM_OF_FIELDS}) {
@@ -438,7 +437,7 @@ sub each_column {
         my $sth_columns = $self->dbh->column_info(undef, undef, $table, '%');
         while (my $column_info = $sth_columns->fetchrow_hashref) {
             my $column = $column_info->{COLUMN_NAME};
-            $cb->($table, $column, $column_info);
+            $self->$cb($table, $column, $column_info);
         }
     }
 }
@@ -466,9 +465,7 @@ sub register_filter {
     return $invocant;
 }
 
-sub register_tag_processor {
-    return shift->query_builder->register_tag_processor(@_);
-}
+sub register_tag { shift->query_builder->register_tag(@_) }
 
 our %VALID_SELECT_ARGS
   = map { $_ => 1 } qw/table column where append relation filter query/;
@@ -593,17 +590,6 @@ sub table {
     return $self->{_tables}{$name};
 }
 
-sub txn_scope {
-    my $self = shift;
-    
-    require DBIx::TransactionManager;
-    
-    $self->{_transaction_manager}
-      ||= DBIx::TransactionManager->new($self->dbh);
-    
-    return $self->{_transaction_manager}->txn_scope;
-}
-
 our %VALID_UPDATE_ARGS
   = map { $_ => 1 } qw/table param
                        where append filter allow_update_all query/;
@@ -731,6 +717,12 @@ sub _croak {
     }
 }
 
+# Following methos are DEPRECATED!
+__PACKAGE__->attr(
+    dbi_options => sub { {} },
+    filter_check  => 1
+);
+
 sub default_bind_filter {
     my $self = shift;
     
@@ -774,6 +766,10 @@ sub default_fetch_filter {
     return $self->{default_in_filter};
 }
 
+sub register_tag_processor {
+    return shift->query_builder->register_tag_processor(@_);
+}
+
 1;
 
 =head1 NAME
@@ -782,67 +778,44 @@ DBIx::Custom - DBI interface, having hash parameter binding and filtering system
 
 =head1 SYNOPSYS
 
-Connect to the database.
-    
     use DBIx::Custom;
     my $dbi = DBIx::Custom->connect(data_source => "dbi:mysql:database=dbname",
-                                    user => 'ken', password => '!LFKD%$&');
-
-Insert, update, and delete
+                                    user => 'ken', password => '!LFKD%$&',
+                                    dbi_option => {mysql_enable_utf8 => 1});
 
     # Insert 
     $dbi->insert(table  => 'book',
                  param  => {title => 'Perl', author => 'Ken'},
-                 filter => {title => 'encode_utf8'});
+                 filter => {title => 'to_something'});
     
     # Update 
     $dbi->update(table  => 'book', 
                  param  => {title => 'Perl', author => 'Ken'}, 
                  where  => {id => 5},
-                 filter => {title => 'encode_utf8'});
+                 filter => {title => 'to_something'});
     
     # Update all
     $dbi->update_all(table  => 'book',
                      param  => {title => 'Perl'},
-                     filter => {title => 'encode_utf8'});
+                     filter => {title => 'to_something'});
     
     # Delete
     $dbi->delete(table  => 'book',
                  where  => {author => 'Ken'},
-                 filter => {title => 'encode_utf8'});
+                 filter => {title => 'to_something'});
     
     # Delete all
     $dbi->delete_all(table => 'book');
 
-Select
-
     # Select
-    my $result = $dbi->select(table => 'book');
-    
-    # Select, more complex
     my $result = $dbi->select(
         table  => 'book',
         column => [qw/author title/],
         where  => {author => 'Ken'},
+        relation => {'book.id' => 'rental.book_id'},
         append => 'order by id limit 5',
-        filter => {title => 'encode_utf8'}
+        filter => {title => 'to_something'}
     );
-    
-    # Select, join table
-    my $result = $dbi->select(
-        table    => ['book', 'rental'],
-        column   => ['book.name as book_name']
-        relation => {'book.id' => 'rental.book_id'}
-    );
-    
-    # Select, more flexible where
-    my $result = $dbi->select(
-        table  => 'book',
-        where  => ['{= author} and {like title}', 
-                   {author => 'Ken', title => '%Perl%'}]
-    );
-
-Execute SQL
 
     # Execute SQL
     $dbi->execute("select title from book");
@@ -850,7 +823,7 @@ Execute SQL
     # Execute SQL with hash binding and filtering
     $dbi->execute("select id from book where {= author} and {like title}",
                   param  => {author => 'ken', title => '%Perl%'},
-                  filter => {title => 'encode_utf8'});
+                  filter => {title => 'to_something'});
 
     # Create query and execute it
     my $query = $dbi->create_query(
@@ -858,13 +831,9 @@ Execute SQL
     );
     $dbi->execute($query, param => {author => 'Ken', title => '%Perl%'})
 
-Other features.
-
     # Get DBI object
     my $dbh = $dbi->dbh;
 
-Fetch row.
-
     # Fetch
     while (my $row = $result->fetch) {
         # ...
@@ -932,10 +901,10 @@ C<connect()> method use this value to connect the database.
 
 L<DBI> object. You can call all methods of L<DBI>.
 
-=head2 C<dbi_options>
+=head2 C<dbi_option>
 
-    my $dbi_options = $dbi->dbi_options;
-    $dbi            = $dbi->dbi_options($dbi_options);
+    my $dbi_option = $dbi->dbi_option;
+    $dbi            = $dbi->dbi_option($dbi_option);
 
 DBI options.
 C<connect()> method use this value to connect the database.
@@ -947,9 +916,6 @@ Default filter when row is fetched.
     my $filters = $dbi->filters;
     $dbi        = $dbi->filters(\%filters);
 
-Filter functions.
-"encode_utf8" and "decode_utf8" is registered by default.
-
 =head2 C<filter_check>
 
     my $filter_check = $dbi->filter_check;
@@ -1068,18 +1034,6 @@ Query is L<DBIx::Custom::Query> object.
 Return value is L<DBIx::Custom::Result> if select statement is executed,
 or the count of affected rows if insert, update, delete statement is executed.
 
-B<Example:>
-
-    my $result = $dbi->execute(
-        "select * from book where {= author} and {like title}", 
-        param => {author => 'Ken', title => '%Perl%'}
-    );
-    
-    while (my $row = $result->fetch) {
-        my $author = $row->[0];
-        my $title  = $row->[1];
-    }
-
 =head2 C<(experimental) expand>
 
     my %expand = $dbi->expand($source);
@@ -1114,13 +1068,6 @@ C<query> is if you don't execute sql and get L<DBIx::Custom::Query> object as re
 default to 0. This is experimental.
 Return value of C<delete()> is the count of affected rows.
 
-B<Example:>
-
-    $dbi->delete(table  => 'book',
-                 where  => {id => 5},
-                 append => 'some statement',
-                 filter => {id => 'encode_utf8'});
-
 =head2 C<delete_all>
 
     $dbi->delete_all(table => $table);
@@ -1130,10 +1077,6 @@ Arguments is same as C<delete> method,
 except that C<delete_all> don't have C<where> argument.
 Return value of C<delete_all()> is the count of affected rows.
 
-B<Example:>
-    
-    $dbi->delete_all(table => 'book');
-
 =head2 C<(experimental) helper>
 
     $dbi->helper(
@@ -1172,13 +1115,6 @@ default to 0. This is experimental.
 This is overwrites C<default_bind_filter>.
 Return value of C<insert()> is the count of affected rows.
 
-B<Example:>
-
-    $dbi->insert(table  => 'book', 
-                 param  => {title => 'Perl', author => 'Taro'},
-                 append => "some statement",
-                 filter => {title => 'encode_utf8'})
-
 =head2 C<new>
 
     my $dbi = DBIx::Custom->connect(data_source => "dbi:mysql:database=dbname",
@@ -1235,28 +1171,9 @@ C<default_filter> and C<filter> of C<DBIx::Custom::Result>
 
 =back
 
-B<Example:>
+=head2 C<register_tag>
 
-    $dbi->register_filter(
-        encode_utf8 => sub {
-            my $value = shift;
-            
-            require Encode;
-            
-            return Encode::encode('UTF-8', $value);
-        },
-        decode_utf8 => sub {
-            my $value = shift;
-            
-            require Encode;
-            
-            return Encode::decode('UTF-8', $value)
-        }
-    );
-
-=head2 C<register_tag_processor>
-
-    $dbi->register_tag_processor(
+    $dbi->register_tag(
         limit => sub {
             ...;
         }
@@ -1291,30 +1208,6 @@ C<filter> is filters when parameter binding is executed.
 C<query> is if you don't execute sql and get L<DBIx::Custom::Query> object as return value.
 default to 0. This is experimental.
 
-B<Example:>
-
-    # select * from book;
-    my $result = $dbi->select(table => 'book');
-    
-    # select * from book where title = ?;
-    my $result = $dbi->select(table => 'book', where => {title => 'Perl'});
-    
-    # select title, author from book where id = ? for update;
-    my $result = $dbi->select(
-        table  => 'book',
-        column => ['title', 'author'],
-        where  => {id => 1},
-        appned => 'for update'
-    );
-    
-    # select book.name as book_name from book, rental
-    # where book.id = rental.book_id;
-    my $result = $dbi->select(
-        table    => ['book', 'rental'],
-        column   => ['book.name as book_name']
-        relation => {'book.id' => 'rental.book_id'}
-    );
-
 If you use more complex condition,
 you can specify a array reference to C<where> argument.
 
@@ -1351,29 +1244,6 @@ default to 0. This is experimental.
 This is overwrites C<default_bind_filter>.
 Return value of C<update()> is the count of affected rows.
 
-B<Example:>
-
-    $dbi->update(table  => 'book',
-                 param  => {title => 'Perl', author => 'Taro'},
-                 where  => {id => 5},
-                 append => "some statement",
-                 filter => {title => 'encode_utf8'});
-
-=head2 C<(experimental) txn_scope>
-
-    {
-        my $txn = $dbi->txn_scope;
-        $dbi->insert(table => 'book', param => {title => 'Perl'});
-        $dbi->insert(table => 'book', param => {title => 'Good days'});
-        $txn->commit;
-    }
-
-Create transaction scope. If you escape scope(that is { .. }) and commited,
-Rollback is automatically done.
-
-Note that this is feature of L<DBIx::TransactionManager>
-L<DBIx::TransactionManager> is required.
-
 =head2 C<(experimental) table>
 
     $dbi->table('book',
@@ -1398,12 +1268,6 @@ Arguments is same as C<update> method,
 except that C<update_all> don't have C<where> argument.
 Return value of C<update_all()> is the count of affected rows.
 
-B<Example:>
-
-    $dbi->update_all(table  => 'book', 
-                     param  => {author => 'taro'},
-                     filter => {author => 'encode_utf8'});
-
 =head2 C<(experimental) where>
 
     my $where = $dbi->where;
@@ -1417,23 +1281,6 @@ Create a new L<DBIx::Custom::Where> object.
 
 Method to set and get caches.
 
-B<Example:>
-
-    $dbi->cache_method(
-        sub {
-            my $self = shift;
-            
-            $self->{_cached} ||= {};
-            
-            if (@_ > 1) {
-                $self->{_cached}{$_[0]} = $_[1] 
-            }
-            else {
-                return $self->{_cached}{$_[0]}
-            }
-        }
-    );
-
 =head1 STABILITY
 
 L<DBIx::Custom> is now stable. APIs keep backword compatible in the feature.
